==> haskell-skylighting-format-context-0.1.0.2-101-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-context.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 skylighting-format-context
version:              0.1.0.2
visibility:           public
id:                   skylighting-format-context-0.1.0.2-LqHcG4E2Ae8DU71ghJnVKy
key:                  skylighting-format-context-0.1.0.2-LqHcG4E2Ae8DU71ghJnVKy
license:              BSD-3-Clause
copyright:            © Albert Krewinkel, John MacFarlane
maintainer:           albert@tarleb.com
author:               Albert Krewinkel
homepage:             https://github.com/jgm/skylighting
synopsis:
    ConTeXt formatter for skylighting syntax highlighting
    library

description:
    This module allows tokens produced by skylighting-core
    to be rendered as ConTeXt commands.

category:             Text
abi:                  428ed08d4f521eabd97685fe59fff137
exposed:              True
exposed-modules:      Skylighting.Format.ConTeXt
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/skylighting-format-context-0.1.0.2

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/skylighting-format-context-0.1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-context
hs-libraries:         HSskylighting-format-context-0.1.0.2-LqHcG4E2Ae8DU71ghJnVKy
depends:
    base-4.16.4.0 containers-0.6.5.1
    skylighting-core-0.14.1.1-u97SV1sV2S8CVrcDKqoQm text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-context/html/skylighting-format-context.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-context/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-format-context-0.1.0.2-103-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-context.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 skylighting-format-context
version:              0.1.0.2
visibility:           public
id:                   skylighting-format-context-0.1.0.2-BnTPuw07h4IFQcwMQhiZBO
key:                  skylighting-format-context-0.1.0.2-BnTPuw07h4IFQcwMQhiZBO
license:              BSD-3-Clause
copyright:            © Albert Krewinkel, John MacFarlane
maintainer:           albert@tarleb.com
author:               Albert Krewinkel
homepage:             https://github.com/jgm/skylighting
synopsis:
    ConTeXt formatter for skylighting syntax highlighting
    library

description:
    This module allows tokens produced by skylighting-core
    to be rendered as ConTeXt commands.

category:             Text
abi:                  a8aabad529906430181d55e0e75d765b
exposed:              True
exposed-modules:      Skylighting.Format.ConTeXt
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/skylighting-format-context-0.1.0.2

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/skylighting-format-context-0.1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-context
hs-libraries:         HSskylighting-format-context-0.1.0.2-BnTPuw07h4IFQcwMQhiZBO
depends:
    base-4.16.4.0 containers-0.6.5.1
    skylighting-core-0.14.1.1-9nlNY0ensgFGsvIL0uymXn text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-context/html/skylighting-format-context.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-context/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
